==> gimp-1.3.1.tar.bz2: gimp-1.3.1/app/core/gimpimage-contiguous-region.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_IMAGE_CONTIGUOUS_REGION_H__
#define __GIMP_IMAGE_CONTIGUOUS_REGION_H__


GimpChannel * gimp_image_contiguous_region_by_seed  (GimpImage     *gimage,
                                                     GimpDrawable  *drawable,
                                                     gboolean       sample_merged,
                                                     gboolean       antialias,
                                                     gint           threshold,
                                                     gint           x,
                                                     gint           y);

GimpChannel * gimp_image_contiguous_region_by_color (GimpImage     *gimage,
                                                     GimpDrawable  *drawable,
                                                     gboolean       sample_merged,
                                                     gboolean       antialias,
                                                     gint           threshold,
                                                     const GimpRGB *color);


#endif  /*  __GIMP_IMAGE_CONTIGUOUS_REGION_H__ */

==> gimp-2.3.8.tar.bz2: gimp-2.3.8/app/core/gimpimage-contiguous-region.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_IMAGE_CONTIGUOUS_REGION_H__
#define __GIMP_IMAGE_CONTIGUOUS_REGION_H__


GimpChannel * gimp_image_contiguous_region_by_seed  (GimpImage     *image,
                                                     GimpDrawable  *drawable,
                                                     gboolean       sample_merged,
                                                     gboolean       antialias,
                                                     gint           threshold,
                                                     gboolean       select_transparent,
                                                     gint           x,
                                                     gint           y);

GimpChannel * gimp_image_contiguous_region_by_color (GimpImage     *image,
                                                     GimpDrawable  *drawable,
                                                     gboolean       sample_merged,
                                                     gboolean       antialias,
                                                     gint           threshold,
                                                     gboolean       select_transparent,
                                                     const GimpRGB *color);


#endif  /*  __GIMP_IMAGE_CONTIGUOUS_REGION_H__ */
